abacusai.null_violation — AbacusAI documentation

# abacusai.null_violation

## Classes

`NullViolation` | Summary of anomalous null frequencies for a feature discovered by a model monitoring instance

## Module Contents

class abacusai.null_violation.NullViolation(client, name=None, violation=None, trainingNullFreq=None, predictionNullFreq=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of anomalous null frequencies for a feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - violation (str) – Description of null violation for a prediction feature.

    - trainingNullFreq (float) – Proportion of null entries in training feature.

    - predictionNullFreq (float) – Proportion of null entries in prediction feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict